# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.hos_daily_logs_update_shipping_docs_response_body import HosDailyLogsUpdateShippingDocsResponseBody
from .raw_client import AsyncRawBetaClient, RawBetaClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class BetaClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawBetaClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawBetaClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawBetaClient
        """
        return self._raw_client

    def update_shipping_docs(
        self,
        *,
        hos_date: str,
        driver_id: str,
        shipping_docs: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HosDailyLogsUpdateShippingDocsResponseBody:
        """
        Update the shippingDocs field of an existing assignment.

         <b>Rate limit:</b> 5 requests/sec (learn more about rate limits <a href="https://developers.samsara.com/docs/rate-limits" target="_blank">here</a>).

        To use this endpoint, select **Write ELD Hours of Service (US)** under the Compliance category when creating or editing an API token. <a href="https://developers.samsara.com/docs/authentication#scopes-for-api-tokens" target="_blank">Learn More.</a>


         **Submit Feedback**: Likes, dislikes, and API feature requests should be filed as feedback in our <a href="https://forms.gle/zkD4NCH7HjKb7mm69" target="_blank">API feedback form</a>. If you encountered an issue or noticed inaccuracies in the API documentation, please <a href="https://www.samsara.com/help" target="_blank">submit a case</a> to our support team.

        Parameters
        ----------
        hos_date : str
            A start date in yyyy-mm-dd format. Required.

        driver_id : str
            ID of the driver for whom the duty status is being set.

        shipping_docs : str
            ShippingDocs associated with the driver for the day.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HosDailyLogsUpdateShippingDocsResponseBody
            OK response.

        Examples
        --------
        from samsara import Samsara

        client = Samsara(
            token="YOUR_TOKEN",
        )
        client.beta.update_shipping_docs(
            hos_date="hosDate",
            driver_id="driverID",
            shipping_docs="ShippingID1, ShippingID2",
        )
        """
        _response = self._raw_client.update_shipping_docs(
            hos_date=hos_date, driver_id=driver_id, shipping_docs=shipping_docs, request_options=request_options
        )
        return _response.data


class AsyncBetaClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawBetaClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawBetaClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawBetaClient
        """
        return self._raw_client

    async def update_shipping_docs(
        self,
        *,
        hos_date: str,
        driver_id: str,
        shipping_docs: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HosDailyLogsUpdateShippingDocsResponseBody:
        """
        Update the shippingDocs field of an existing assignment.

         <b>Rate limit:</b> 5 requests/sec (learn more about rate limits <a href="https://developers.samsara.com/docs/rate-limits" target="_blank">here</a>).

        To use this endpoint, select **Write ELD Hours of Service (US)** under the Compliance category when creating or editing an API token. <a href="https://developers.samsara.com/docs/authentication#scopes-for-api-tokens" target="_blank">Learn More.</a>


         **Submit Feedback**: Likes, dislikes, and API feature requests should be filed as feedback in our <a href="https://forms.gle/zkD4NCH7HjKb7mm69" target="_blank">API feedback form</a>. If you encountered an issue or noticed inaccuracies in the API documentation, please <a href="https://www.samsara.com/help" target="_blank">submit a case</a> to our support team.

        Parameters
        ----------
        hos_date : str
            A start date in yyyy-mm-dd format. Required.

        driver_id : str
            ID of the driver for whom the duty status is being set.

        shipping_docs : str
            ShippingDocs associated with the driver for the day.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HosDailyLogsUpdateShippingDocsResponseBody
            OK response.

        Examples
        --------
        import asyncio

        from samsara import AsyncSamsara

        client = AsyncSamsara(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.beta.update_shipping_docs(
                hos_date="hosDate",
                driver_id="driverID",
                shipping_docs="ShippingID1, ShippingID2",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_shipping_docs(
            hos_date=hos_date, driver_id=driver_id, shipping_docs=shipping_docs, request_options=request_options
        )
        return _response.data
