# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.request_options import RequestOptions
from ....types.idling_reports_get_vehicle_idling_reports_response_body import (
    IdlingReportsGetVehicleIdlingReportsResponseBody,
)
from .raw_client import AsyncRawIdlingClient, RawIdlingClient


class IdlingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawIdlingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawIdlingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawIdlingClient
        """
        return self._raw_client

    def get(
        self,
        *,
        start_time: str,
        end_time: str,
        after: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        vehicle_ids: typing.Optional[str] = None,
        tag_ids: typing.Optional[str] = None,
        parent_tag_ids: typing.Optional[str] = None,
        is_pto_active: typing.Optional[bool] = None,
        min_idling_duration_minutes: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> IdlingReportsGetVehicleIdlingReportsResponseBody:
        """
        Get all vehicle idling reports for the requested time duration.

         <b>Rate limit:</b> 25 requests/sec (learn more about rate limits <a href="https://developers.samsara.com/docs/rate-limits" target="_blank">here</a>).

        To use this endpoint, select **Read Fuel & Energy** under the Fuel & Energy category when creating or editing an API token. <a href="https://developers.samsara.com/docs/authentication#scopes-for-api-tokens" target="_blank">Learn More.</a>


         **Submit Feedback**: Likes, dislikes, and API feature requests should be filed as feedback in our <a href="https://forms.gle/zkD4NCH7HjKb7mm69" target="_blank">API feedback form</a>. If you encountered an issue or noticed inaccuracies in the API documentation, please <a href="https://www.samsara.com/help" target="_blank">submit a case</a> to our support team.

        Parameters
        ----------
        start_time : str
             A start time in RFC 3339 format. Defaults to now if not provided. Millisecond precision and timezones are supported. Note that the most recent 72 hours of data may still be processing and is subject to change and latency, so it is not recommended to request data for the most recent 72 hours. (Examples: 2019-06-13T19:08:25Z, 2019-06-13T19:08:25.455Z, OR 2015-09-15T14:00:12-04:00).

        end_time : str
             An end time in RFC 3339 format. Defaults to now if not provided. Millisecond precision and timezones are supported. Note that the most recent 72 hours of data may still be processing and is subject to change and latency, so it is not recommended to request data for the most recent 72 hours. (Examples: 2019-06-13T19:08:25Z, 2019-06-13T19:08:25.455Z, OR 2015-09-15T14:00:12-04:00).

        after : typing.Optional[str]
             If specified, this should be the endCursor value from the previous page of results. When present, this request will return the next page of results that occur immediately after the previous page of results.

        limit : typing.Optional[int]
            The limit for how many objects will be in the response. Default and max for this value is 512 objects.

        vehicle_ids : typing.Optional[str]
             A filter on the data based on this comma-separated list of vehicle IDs and externalIds. Example: `vehicleIds=1234,5678,samsara.vin:1HGBH41JXMN109186`

        tag_ids : typing.Optional[str]
             A filter on the data based on this comma-separated list of tag IDs. Example: `tagIds=1234,5678`

        parent_tag_ids : typing.Optional[str]
             A filter on the data based on this comma-separated list of parent tag IDs, for use by orgs with tag hierarchies. Specifying a parent tag will implicitly include all descendent tags of the parent tag. Example: `parentTagIds=345,678`

        is_pto_active : typing.Optional[bool]
            A filter on the data based on power take-off being active or inactive.

        min_idling_duration_minutes : typing.Optional[int]
            A filter on the data based on a minimum idling duration.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        IdlingReportsGetVehicleIdlingReportsResponseBody
            OK response.

        Examples
        --------
        from samsara import Samsara

        client = Samsara(
            token="YOUR_TOKEN",
        )
        client.reports.vehicles.idling.get(
            start_time="startTime",
            end_time="endTime",
        )
        """
        _response = self._raw_client.get(
            start_time=start_time,
            end_time=end_time,
            after=after,
            limit=limit,
            vehicle_ids=vehicle_ids,
            tag_ids=tag_ids,
            parent_tag_ids=parent_tag_ids,
            is_pto_active=is_pto_active,
            min_idling_duration_minutes=min_idling_duration_minutes,
            request_options=request_options,
        )
        return _response.data


class AsyncIdlingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawIdlingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawIdlingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawIdlingClient
        """
        return self._raw_client

    async def get(
        self,
        *,
        start_time: str,
        end_time: str,
        after: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        vehicle_ids: typing.Optional[str] = None,
        tag_ids: typing.Optional[str] = None,
        parent_tag_ids: typing.Optional[str] = None,
        is_pto_active: typing.Optional[bool] = None,
        min_idling_duration_minutes: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> IdlingReportsGetVehicleIdlingReportsResponseBody:
        """
        Get all vehicle idling reports for the requested time duration.

         <b>Rate limit:</b> 25 requests/sec (learn more about rate limits <a href="https://developers.samsara.com/docs/rate-limits" target="_blank">here</a>).

        To use this endpoint, select **Read Fuel & Energy** under the Fuel & Energy category when creating or editing an API token. <a href="https://developers.samsara.com/docs/authentication#scopes-for-api-tokens" target="_blank">Learn More.</a>


         **Submit Feedback**: Likes, dislikes, and API feature requests should be filed as feedback in our <a href="https://forms.gle/zkD4NCH7HjKb7mm69" target="_blank">API feedback form</a>. If you encountered an issue or noticed inaccuracies in the API documentation, please <a href="https://www.samsara.com/help" target="_blank">submit a case</a> to our support team.

        Parameters
        ----------
        start_time : str
             A start time in RFC 3339 format. Defaults to now if not provided. Millisecond precision and timezones are supported. Note that the most recent 72 hours of data may still be processing and is subject to change and latency, so it is not recommended to request data for the most recent 72 hours. (Examples: 2019-06-13T19:08:25Z, 2019-06-13T19:08:25.455Z, OR 2015-09-15T14:00:12-04:00).

        end_time : str
             An end time in RFC 3339 format. Defaults to now if not provided. Millisecond precision and timezones are supported. Note that the most recent 72 hours of data may still be processing and is subject to change and latency, so it is not recommended to request data for the most recent 72 hours. (Examples: 2019-06-13T19:08:25Z, 2019-06-13T19:08:25.455Z, OR 2015-09-15T14:00:12-04:00).

        after : typing.Optional[str]
             If specified, this should be the endCursor value from the previous page of results. When present, this request will return the next page of results that occur immediately after the previous page of results.

        limit : typing.Optional[int]
            The limit for how many objects will be in the response. Default and max for this value is 512 objects.

        vehicle_ids : typing.Optional[str]
             A filter on the data based on this comma-separated list of vehicle IDs and externalIds. Example: `vehicleIds=1234,5678,samsara.vin:1HGBH41JXMN109186`

        tag_ids : typing.Optional[str]
             A filter on the data based on this comma-separated list of tag IDs. Example: `tagIds=1234,5678`

        parent_tag_ids : typing.Optional[str]
             A filter on the data based on this comma-separated list of parent tag IDs, for use by orgs with tag hierarchies. Specifying a parent tag will implicitly include all descendent tags of the parent tag. Example: `parentTagIds=345,678`

        is_pto_active : typing.Optional[bool]
            A filter on the data based on power take-off being active or inactive.

        min_idling_duration_minutes : typing.Optional[int]
            A filter on the data based on a minimum idling duration.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        IdlingReportsGetVehicleIdlingReportsResponseBody
            OK response.

        Examples
        --------
        import asyncio

        from samsara import AsyncSamsara

        client = AsyncSamsara(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.reports.vehicles.idling.get(
                start_time="startTime",
                end_time="endTime",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(
            start_time=start_time,
            end_time=end_time,
            after=after,
            limit=limit,
            vehicle_ids=vehicle_ids,
            tag_ids=tag_ids,
            parent_tag_ids=parent_tag_ids,
            is_pto_active=is_pto_active,
            min_idling_duration_minutes=min_idling_duration_minutes,
            request_options=request_options,
        )
        return _response.data
